==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpSearchResult.java <==
package io.qt.help;


/**
 * <p>The data associated with the search result</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html">QHelpSearchResult</a></p>
 */
public class QHelpSearchResult extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html#QHelpSearchResult">QHelpSearchResult::QHelpSearchResult()</a></p>
     */
    public QHelpSearchResult(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QHelpSearchResult instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html#QHelpSearchResult-1">QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)</a></p>
     */
    public QHelpSearchResult(io.qt.help.QHelpSearchResult other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QHelpSearchResult instance, io.qt.help.QHelpSearchResult other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html#QHelpSearchResult-2">QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)</a></p>
     */
    public QHelpSearchResult(io.qt.core.QUrl url, java.lang.String title, java.lang.String snippet){
        super((QPrivateConstructor)null);
        initialize_native(this, url, title, snippet);
    }
    
    private native static void initialize_native(QHelpSearchResult instance, io.qt.core.QUrl url, java.lang.String title, java.lang.String snippet);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html#snippet">QHelpSearchResult::snippet()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String snippet(){
        return snippet_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String snippet_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html#title">QHelpSearchResult::title()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresult.html#url">QHelpSearchResult::url()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchResult(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QHelpSearchResult clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QHelpSearchResult clone_native(long __this_nativeId);
}

==> qtjambi-help-6.2.5-sources.jar: io/qt/help/QHelpSearchResult.java <==
package io.qt.help;


/**
 * <p>The data associated with the search result</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpsearchresult.html">QHelpSearchResult</a></p>
 */
public class QHelpSearchResult extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresult.html#QHelpSearchResult">QHelpSearchResult::QHelpSearchResult()</a></p>
     */
    public QHelpSearchResult(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QHelpSearchResult instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresult.html#QHelpSearchResult-1">QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)</a></p>
     */
    public QHelpSearchResult(io.qt.help.QHelpSearchResult other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QHelpSearchResult instance, io.qt.help.QHelpSearchResult other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresult.html#QHelpSearchResult-2">QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)</a></p>
     */
    public QHelpSearchResult(io.qt.core.QUrl url, java.lang.String title, java.lang.String snippet){
        super((QPrivateConstructor)null);
        initialize_native(this, url, title, snippet);
    }
    
    private native static void initialize_native(QHelpSearchResult instance, io.qt.core.QUrl url, java.lang.String title, java.lang.String snippet);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresult.html#snippet">QHelpSearchResult::snippet()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String snippet(){
        return snippet_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String snippet_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresult.html#title">QHelpSearchResult::title()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresult.html#url">QHelpSearchResult::url()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchResult(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QHelpSearchResult clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QHelpSearchResult clone_native(long __this_nativeId);
}
